..
    This file is part of kwalitee
    Copyright (C) 2014, 2015 CERN.

    kwalitee is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    kwalitee is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with kwalitee; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

    In applying this licence, CERN does not waive the privileges and immunities
    granted to it by virtue of its status as an Intergovernmental Organization
    or submit itself to any jurisdiction.


Authors
-------

kwalitee is developed to support developers of
`Invenio <http://invenio-software.org>`_ digital library software.

Contact us at `info@invenio-software.org <mailto:info@invenio-software.org>`_.

Contributors
^^^^^^^^^^^^

* Jiri Kuncar <jiri.kuncar@cern.ch>
* Yoan Blanc <yoan@dosimple.ch>
* Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
* Mateusz Susik <mateuszsusik@gmail.com>
* Harris Tzovanakis <me@drjova.com>
* Leonardo Rossi <leonardo.r@cern.ch>
* Tibor Simko <tibor.simko@cern.ch>
